==> open-xchange-appsuite-backend_7.2.1.orig.tar.bz2: open-xchange-appsuite-backend-7.2.1/com.openexchange.printing/src/com/openexchange/printing/TimeSpanFormatter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing;

import java.util.Date;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.calendar.itip.Messages;
import com.openexchange.i18n.tools.StringHelper;
import com.openexchange.java.StringAllocator;

/**
 * {@link CalendarFormatter}
 * 
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco
 *         Laguna</a>
 */
public class TimeSpanFormatter extends DateFormatter {
	
	private Map<String, Object> timespanThingy;

	public TimeSpanFormatter(Map<String, Object> timeSpanThingy, Locale locale, TimeZone tz) {
		super(locale, tz);
		this.timespanThingy = timeSpanThingy;
	}

	public String getInterval() {
		return formatInterval(timespanThingy);
	}


	public String formatDate(Date startDate, Date endDate, boolean isFullTime) {
	
		if (isFullTime) {
			endDate = new Date(endDate.getTime() - 1000);
		}
	
		if (differentDays(startDate, endDate)) {
			if (isFullTime) {
				return String.format("%s - %s", formatDate(startDate, utc),
						formatDate(endDate, utc));
			} else {
				return String.format("%s - %s", formatDate(startDate),
						formatDate(endDate));
			}
		} else {
			return formatDate(startDate);
		}
	}
	public String formatDate(Map<String, Object> appointment) {
		Date startDate = new Date((Long) appointment.get("start_date"));
		Date endDate = new Date((Long) appointment.get("end_date"));
		return formatDate(startDate, endDate, isFullTime());
	}

	public String formatInterval(Map<String, Object> appointment) {
		if (isFullTime()) {
			return StringHelper.valueOf(locale).getString(Messages.FULL_TIME);
		}
		Date startDate = new Date((Long) appointment.get("start_date"));
		Date endDate = new Date((Long) appointment.get("end_date"));
		return formatInterval(startDate, endDate, isFullTime());
	}

	public String getDateSpec() {
		StringAllocator b = new StringAllocator();
		b.append(formatDate(timespanThingy));
		return b.toString();
	}

	private boolean isFullTime() {
		Boolean fullTime = (Boolean) timespanThingy.get("full_time");
		return fullTime == null || fullTime;
	}

}

==> open-xchange-appsuite-backend_7.4.1.orig.tar.bz2: open-xchange-appsuite-backend-7.4.1/com.openexchange.printing/src/com/openexchange/printing/TimeSpanFormatter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing;

import java.util.Date;
import java.util.Locale;
import java.util.Map;
import java.util.TimeZone;
import com.openexchange.calendar.itip.Messages;
import com.openexchange.i18n.tools.StringHelper;
import com.openexchange.java.StringAllocator;

/**
 * {@link CalendarFormatter}
 * 
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco
 *         Laguna</a>
 */
public class TimeSpanFormatter extends DateFormatter {
	
	private final Map<String, Object> timespanThingy;

	public TimeSpanFormatter(Map<String, Object> timeSpanThingy, Locale locale, TimeZone tz) {
		super(locale, tz);
		this.timespanThingy = timeSpanThingy;
	}

	public String getInterval() {
		return formatInterval(timespanThingy);
	}


	public String formatDate(Date startDate, Date endDate, boolean isFullTime) {
	
		if (isFullTime) {
			endDate = new Date(endDate.getTime() - 1000);
		}
	
		if (differentDays(startDate, endDate)) {
			if (isFullTime) {
				return String.format("%s - %s", formatDate(startDate, utc),
						formatDate(endDate, utc));
			} else {
				return String.format("%s - %s", formatDate(startDate),
						formatDate(endDate));
			}
		} else {
			return formatDate(startDate);
		}
	}
	public String formatDate(Map<String, Object> appointment) {
		Date startDate = new Date((Long) appointment.get("start_date"));
		Date endDate = new Date((Long) appointment.get("end_date"));
		return formatDate(startDate, endDate, isFullTime());
	}

	public String formatInterval(Map<String, Object> appointment) {
		if (isFullTime()) {
			return StringHelper.valueOf(locale).getString(Messages.FULL_TIME);
		}
		Date startDate = new Date((Long) appointment.get("start_date"));
		Date endDate = new Date((Long) appointment.get("end_date"));
		return formatInterval(startDate, endDate, isFullTime());
	}

	public String getDateSpec() {
		StringAllocator b = new StringAllocator();
		b.append(formatDate(timespanThingy));
		return b.toString();
	}

	private boolean isFullTime() {
		Boolean fullTime = (Boolean) timespanThingy.get("full_time");
		return fullTime == null || fullTime;
	}

}
